@@ -4,7 +4,6 @@ import networkx as nx
 
 from shut.commands.pkg.install import collect_requirement_args, run_install, split_extras
 from shut.model.monorepo import MonorepoModel
-from shut.model.requirements import RequirementsList
 from . import mono, project
 
 
@@ -37,4 +36,4 @@ def install(develop, extra, upgrade, quiet, pip, pip_args, dry):
   if pip_args:
     args += shlex.split(pip_args)
 
-  run_install(pip, args, develop, upgrade, quiet, dry)
+  run_install(pip, args, upgrade, quiet, dry)
